#
# spec file for package lzma-sdk
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _sver   1806
%define _maver  18
%define _miver  05
Name:           lzma-sdk
Version:        18.06
Release:        18.5
Summary:        An implementation of LZMA compression
# Actually the site says "Public Domain". See license file.
License:        LGPL-2.1-only
Group:          Productivity/Archiving/Compression
URL:            http://www.7-zip.org/sdk.html
Source0:        http://www.7-zip.org/a/lzma%{_sver}.7z
Source1:        lzma-sdk-LICENSE.fedora
Patch1:         lzma-sdk-shlib.patch
BuildRequires:  automake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  p7zip-full
BuildRequires:  pkg-config

%description
LZMA SDK provides documentation, samples, header files, libraries,
and tools for developing applications with LZMA support.

LZMA uses a dictionary compression algorithm (a variant of LZ77, with
huge dictionary sizes and special support for repeatedly used match
distances), whose output is then encoded with a range encoder, using
a model to make a probability prediction of each bit.
LZMA yields around 20%% better compression when operating at approximately
zlib's speed, and around 40%% when trading more time.

%package devel
Summary:        Development libraries and headers for %{name}
Group:          Development/Languages/C and C++
Requires:       libclzma-suse0 = %{version}

%description devel
This package contains development libraries and headers for %{name}.

%package -n libclzma-suse0
Summary:        LZMA stream encoding/decoding library from 7-Zip
Group:          System/Libraries

%description -n libclzma-suse0
Library for encoding/decoding LZMA streams, using the 7-Zip library
implementation.

%prep
%setup -q -c -n lzma%{_sver}
%patch -P 1 -p1
perl -i -pe 's{AC_INIT.*}{AC_INIT([lzma-sdk], [%version])}' configure.ac
dos2unix DOC/*.txt
install -p -m 0644 %{SOURCE1} .

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n libclzma-suse0 -p /sbin/ldconfig
%postun -n libclzma-suse0 -p /sbin/ldconfig

%files -n libclzma-suse0
%license lzma-sdk-LICENSE.fedora
%doc DOC/lzma.txt DOC/lzma-history.txt
%{_libdir}/libclzma-suse.so.0*

%files devel
%license lzma-sdk-LICENSE.fedora
%doc DOC/7z*.txt DOC/Methods.txt
%{_includedir}/clzma/
%{_libdir}/libclzma.so
%{_libdir}/pkgconfig/clzma.pc

%changelog
* Sun Dec 30 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 18.06
  * The speed for LZMA/LZMA2 compressing was increased by 3-10%%,
    and there are minor changes in compression ratio.
  * Some bugs were fixed.
  * The bug in 7-Zip 18.02-18.05 was fixed:
    There was memory leak in multithreading xz decoder -
    XzDecMt_Decode(), if xz stream contains only one block.
  * The changes for MSVS compiler makefiles:
    + the makefiles now use "PLATFORM" macroname with values
    (x64, x86, arm64) instead of "CPU" macroname with values
    (AMD64, ARM64).
    + the makefiles by default now use static version of the
    run-time library.
* Mon Jun 11 2018 aloisio@gmx.com
- Fixed unpacking problem
* Tue May  1 2018 aloisio@gmx.com
- Update to version 18.05
  * The speed for LZMA/LZMA2 compressing was increased
    by 8%% for fastest/fast compression levels and
    by 3%% for normal/maximum compression levels.
  * The BUG was fixed in Lzma2Enc.c
    Lzma2Enc_Encode2() function worked incorretly,
    if (inStream == NULL) and the number of block threads is
    more than 1.
- Refreshed lzma-sdk-shlib.patch
* Sat Mar 10 2018 aloisio@gmx.com
- Update to version 18.03
  * Asm\x86\LzmaDecOpt.asm: new optimized LZMA decoder written in
    asm for x64 with about 30%% higher speed than main version of
    LZMA decoder written in C.
  * The speed for single-thread LZMA/LZMA2 decoder written in C
    was increased by 3%%.
- Refreshed lzma-sdk-shlib.patch
* Mon Jan 29 2018 aloisio@gmx.com
- Update to version 18.01
  * Some changes in LZMA2/xz multithreading code for compressing.
    Some bugs were fixed.
* Mon Jan  8 2018 jengelh@inai.de
- Update to new upstream release 17.01
  * Some bugs were fixed.
- Replace lzma-sdk-16.04-sharedlib.patch with lzma-sdk-shlib.patch.
* Tue May 16 2017 jengelh@inai.de
- Trim/update description. Redo .pc file generation so that the
  resulting file looks like other .pc files on openSUSE.
* Thu May 11 2017 aloisio@gmx.com
- Refreshed lzma-sdk-16.04-sharedlib.patch to add source to
  the library to have extra functions and exported extra
  symbols
* Fri Mar 17 2017 aloisio@gmx.com
- Initial package (version 16.04)
